==> tutti-ui-swing-0.2.5-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/macrowaste/MacroWasteBatchTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.macrowaste;

/*
 * #%L
 * Tutti :: UI
 * $Id: MacroWasteBatchTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.2.5/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/macrowaste/MacroWasteBatchTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MacroWasteBatchTableModel extends AbstractTuttiTableModel<MacroWasteBatchRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<MacroWasteBatchRowModel> MACRO_WASTE_CATEGORY = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_MACRO_WASTE_CATEGORY,
            n_("tutti.table.macrowaste.batch.header.macroWasteCategory"),
            n_("tutti.table.macrowaste.batch.header.macroWasteCategory"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> MACRO_WASTE_SIZE_CATEGORY = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_MACRO_WASTE_SIZE_CATEGORY,
            n_("tutti.table.macrowaste.batch.header.macroWasteSizeCategory"),
            n_("tutti.table.macrowaste.batch.header.macroWasteSizeCategory"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> WEIGHT = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_WEIGHT,
            n_("tutti.table.macrowaste.batch.header.weight"),
            n_("tutti.table.macrowaste.batch.header.weight"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> NUMBER = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_NUMBER,
            n_("tutti.table.macrowaste.batch.header.number"),
            n_("tutti.table.macrowaste.batch.header.number"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> COMMENT = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_COMMENT,
            n_("tutti.table.macrowaste.batch.header.comment"),
            n_("tutti.table.macrowaste.batch.header.comment"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> ATTACHMENTS = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_ATTACHMENTS,
            n_("tutti.table.macrowaste.batch.header.file"),
            n_("tutti.table.macrowaste.batch.header.file"));

    public MacroWasteBatchTableModel(TableColumnModel columnModel) {
        super(columnModel, true, true);

        setNoneEditableCols();
    }

    @Override
    public MacroWasteBatchRowModel createNewRow() {
        MacroWasteBatchRowModel result = new MacroWasteBatchRowModel();

        // by default empty row is not valid
        result.setValid(false);
        return result;
    }

}

==> tutti-ui-swing-0.3-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/macrowaste/MacroWasteBatchTableModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.catches.macrowaste;

/*
 * #%L
 * Tutti :: UI
 * $Id: MacroWasteBatchTableModel.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/macrowaste/MacroWasteBatchTableModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.util.table.AbstractTuttiTableModel;
import fr.ifremer.tutti.ui.swing.util.table.ColumnIdentifier;

import javax.swing.table.TableColumnModel;

import static org.nuiton.i18n.I18n.n_;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public class MacroWasteBatchTableModel extends AbstractTuttiTableModel<MacroWasteBatchRowModel> {

    private static final long serialVersionUID = 1L;

    public static final ColumnIdentifier<MacroWasteBatchRowModel> MACRO_WASTE_CATEGORY = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_MACRO_WASTE_CATEGORY,
            n_("tutti.table.macrowaste.batch.header.macroWasteCategory"),
            n_("tutti.table.macrowaste.batch.header.macroWasteCategory"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> MACRO_WASTE_SIZE_CATEGORY = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_MACRO_WASTE_SIZE_CATEGORY,
            n_("tutti.table.macrowaste.batch.header.macroWasteSizeCategory"),
            n_("tutti.table.macrowaste.batch.header.macroWasteSizeCategory"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> WEIGHT = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_WEIGHT,
            n_("tutti.table.macrowaste.batch.header.weight"),
            n_("tutti.table.macrowaste.batch.header.weight"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> NUMBER = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_NUMBER,
            n_("tutti.table.macrowaste.batch.header.number"),
            n_("tutti.table.macrowaste.batch.header.number"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> COMMENT = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_COMMENT,
            n_("tutti.table.macrowaste.batch.header.comment"),
            n_("tutti.table.macrowaste.batch.header.comment"));

    public static final ColumnIdentifier<MacroWasteBatchRowModel> ATTACHMENTS = ColumnIdentifier.newId(
            MacroWasteBatchRowModel.PROPERTY_ATTACHMENTS,
            n_("tutti.table.macrowaste.batch.header.file"),
            n_("tutti.table.macrowaste.batch.header.file"));

    public MacroWasteBatchTableModel(TableColumnModel columnModel) {
        super(columnModel, true, true);

        setNoneEditableCols();
    }

    @Override
    public MacroWasteBatchRowModel createNewRow() {
        MacroWasteBatchRowModel result = new MacroWasteBatchRowModel();

        // by default empty row is not valid
        result.setValid(false);
        return result;
    }

}
